@@ -97,3 +97,29 @@ class TestValidateJWTException:
         response = await app.middleware_func(request, call_next)
 
         call_next.assert_called_once()
+    
+    cases = [
+        ('/some/path/f1225763-3eef-4067-b1ab-17d99b126eab/something', True),
+        ('/some/path/f1225763-3eef-4067-b1ab-17d99b126eab/something/', True),
+        ('/some/path/something', False),
+        ('/some/path', False),
+        ('/some/path//something', False),
+        ('/some/path/1234/1234/something', False),
+        ('/path/1234/something', False),
+    ]
+    @pytest.mark.parametrize('path, expected', cases)
+    @patch('styler_rest_framework.middlewares.fastapi.auth_middleware.validate', Mock(return_value=False))
+    async def test_exclude_regex_path(self, path, expected):
+        app = MockFastAPI()
+        auth_middleware.add_auth_middleware(app, 'development', excludes_regex=['^/some/path/(\w|\d|-)+/something/?$'])
+        call_next = AsyncMock()
+        request = Mock()
+        request.headers.get.return_value = 'Bearer some_jwt'
+        request.url.path = path
+
+        response = await app.middleware_func(request, call_next)
+
+        if expected:
+            call_next.assert_called_once()
+        else:
+            assert response.status_code == 401
